==> nextcloud-27.1.7p0.tgz: nextcloud/lib/l10n/az.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "\"configurasiya\" direktoriyasının daxilində yazmaq mümkün deyil",
    "See %s" : "Bax %s",
    "Sample configuration detected" : "Konfiqurasiya nüsxəsi təyin edildi",
    "Authentication" : "Autentifikasiya",
    "Unknown filetype" : "Fayl tipi bəlli deyil.",
    "Invalid image" : "Yalnış şəkil",
    "Files" : "Fayllar",
    "today" : "Bu gün",
    "yesterday" : "dünən",
    "seconds ago" : "saniyələr öncə",
    "__language_name__" : "Azərbaycan dili",
    "Help" : "Kömək",
    "Apps" : "Tətbiqlər",
    "Settings" : "Quraşdırmalar",
    "Users" : "İstifadəçilər",
    "Email" : "Email",
    "Address" : "Ünvan",
    "Profile picture" : "Profil şəkli",
    "About" : "Haqqında",
    "Additional settings" : "Əlavə parametrlər",
    "Oracle connection could not be established" : "Oracle qoşulması alınmır",
    "Set an admin password." : "İnzibatçı şifrəsini təyin et.",
    "You are not allowed to share %s" : "%s-in yayimlanmasına sizə izin verilmir",
    "Sunday" : "Bazar",
    "Monday" : "Bazar ertəsi",
    "Tuesday" : "Çərşənbə axşamı",
    "Wednesday" : "Çərşənbə",
    "Thursday" : "Cümə axşamı",
    "Friday" : "Cümə",
    "Saturday" : "Şənbə",
    "Sun." : "Baz.",
    "Mon." : "Ber.",
    "Tue." : "Çax.",
    "Wed." : "Çər.",
    "Thu." : "Cax.",
    "Fri." : "Cüm.",
    "Sat." : "Şnb.",
    "January" : "Yanvar",
    "February" : "Fevral",
    "March" : "Mart",
    "April" : "Aprel",
    "May" : "May",
    "June" : "İyun",
    "July" : "İyul",
    "August" : "Avqust",
    "September" : "Sentyabr",
    "October" : "Oktyabr",
    "November" : "Noyabr.",
    "December" : "Dekabr",
    "Jan." : "Yan.",
    "Feb." : "Fev.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "May.",
    "Jun." : "İyn.",
    "Jul." : "İyl.",
    "Aug." : "Avq.",
    "Sep." : "Sen.",
    "Oct." : "Okt.",
    "Nov." : "Noy.",
    "Dec." : "Dek.",
    "A valid password must be provided" : "Düzgün şifrə daxil edilməlidir",
    "Application is not enabled" : "Proqram təminatı aktiv edilməyib",
    "Authentication error" : "Təyinat metodikası",
    "Token expired. Please reload page." : "Token vaxtı bitib. Xahiş olunur səhifəni yenidən yükləyəsiniz.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Bu ola bilər ki, cache/accelerator such tərəfindən cağırılıb hansi ki, Zend OPcache və eAccelerator-da olduğu kimidir.",
    "Full name" : "Tam ad",
    "Unknown user" : "Istifadəçi tanınmır ",
    "Oracle username and/or password not valid" : "Oracle istifadəçi adı və/ya şifrəsi düzgün deyil",
    "Set an admin username." : "İnzibatçı istifadəçi adını təyin et.",
    "A valid username must be provided" : "Düzgün istifadəçi adı daxil edilməlidir"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.12.tgz: nextcloud/lib/l10n/az.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "\"configurasiya\" direktoriyasının daxilində yazmaq mümkün deyil",
    "See %s" : "Bax %s",
    "Sample configuration detected" : "Konfiqurasiya nüsxəsi təyin edildi",
    "Authentication" : "Autentifikasiya",
    "Unknown filetype" : "Fayl tipi bəlli deyil.",
    "Invalid image" : "Yalnış şəkil",
    "Files" : "Fayllar",
    "today" : "Bu gün",
    "yesterday" : "dünən",
    "seconds ago" : "saniyələr öncə",
    "__language_name__" : "Azərbaycan dili",
    "Apps" : "Tətbiqlər",
    "Settings" : "Quraşdırmalar",
    "Email" : "Email",
    "Address" : "Ünvan",
    "Profile picture" : "Profil şəkli",
    "About" : "Haqqında",
    "Additional settings" : "Əlavə parametrlər",
    "Oracle connection could not be established" : "Oracle qoşulması alınmır",
    "Set an admin password." : "İnzibatçı şifrəsini təyin et.",
    "You are not allowed to share %s" : "%s-in yayimlanmasına sizə izin verilmir",
    "Sunday" : "Bazar",
    "Monday" : "Bazar ertəsi",
    "Tuesday" : "Çərşənbə axşamı",
    "Wednesday" : "Çərşənbə",
    "Thursday" : "Cümə axşamı",
    "Friday" : "Cümə",
    "Saturday" : "Şənbə",
    "Sun." : "Baz.",
    "Mon." : "Ber.",
    "Tue." : "Çax.",
    "Wed." : "Çər.",
    "Thu." : "Cax.",
    "Fri." : "Cüm.",
    "Sat." : "Şnb.",
    "January" : "Yanvar",
    "February" : "Fevral",
    "March" : "Mart",
    "April" : "Aprel",
    "May" : "May",
    "June" : "İyun",
    "July" : "İyul",
    "August" : "Avqust",
    "September" : "Sentyabr",
    "October" : "Oktyabr",
    "November" : "Noyabr.",
    "December" : "Dekabr",
    "Jan." : "Yan.",
    "Feb." : "Fev.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "May.",
    "Jun." : "İyn.",
    "Jul." : "İyl.",
    "Aug." : "Avq.",
    "Sep." : "Sen.",
    "Oct." : "Okt.",
    "Nov." : "Noy.",
    "Dec." : "Dek.",
    "A valid password must be provided" : "Düzgün şifrə daxil edilməlidir",
    "Application is not enabled" : "Proqram təminatı aktiv edilməyib",
    "Authentication error" : "Təyinat metodikası",
    "Token expired. Please reload page." : "Token vaxtı bitib. Xahiş olunur səhifəni yenidən yükləyəsiniz.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Bu ola bilər ki, cache/accelerator such tərəfindən cağırılıb hansi ki, Zend OPcache və eAccelerator-da olduğu kimidir.",
    "Summary" : "Xülasə"
},
"nplurals=2; plural=(n != 1);");
